/*
 * Prompt for new delay times during a dialing session.  Also, prompts
 * if changes should be saved to disk.  Dialing is suspended during
 * this routine.
 */

#include <stdio.h>
#include <curses.h>
#include "misc.h"
#include "param.h"

void
delay_times()
{
	WINDOW *dt_win, *newwin();
	int cdelay, pause;

	dt_win = newwin(9, 45, 7, 15);

	mvwprintw(dt_win, 2, 4, "Current carrier delay time: %d", param->cdelay);
	mvwprintw(dt_win, 3, 4, "Current pause between redials: %d", param->pause);
	mvwaddstr(dt_win, 5, 4, "New carrier delay: ");
	mvwaddstr(dt_win, 6, 4, "New pause time: ");
	box(dt_win, '|', '-');

	mvwattrstr(dt_win, 0, 3, A_BOLD, " Change delay times ");
	wmove(dt_win, 5, 23);
	wrefresh(dt_win);
					/* get the cdelay number */
	if ((cdelay = get_num(dt_win, 3)) == -1) {
		delwin(dt_win);
		return;
	}
					/* give 'em the current settings */
	if (!cdelay) {
		cdelay = param->cdelay;
		wprintw(dt_win, "%-3d", cdelay);
	}
	else {
					/* some reasonable limit */
		if (cdelay > MAX_CDELAY || cdelay < MIN_CDELAY) {
			beep();
			if (cdelay > MAX_CDELAY)
				cdelay = MAX_CDELAY;
			else
				cdelay = MIN_CDELAY;
			mvwprintw(dt_win, 5, 23, "%-3d", cdelay);
		}
	}
					/* get the pause number */
	wmove(dt_win, 6, 20);
	wrefresh(dt_win);
	if ((pause = get_num(dt_win, 3)) == -1) {
		delwin(dt_win);
		return;
	}
					/* give 'em the current settings */
	if (!pause) {
		pause = param->pause;
		wprintw(dt_win, "%-3d", pause);
	}
	else {
					/* some reasonable limit */
		if (pause > MAX_PAUSE || pause < MIN_PAUSE) {
			beep();
			if (pause > MAX_PAUSE)
				pause = MAX_PAUSE;
			else
				pause = MIN_PAUSE;
			mvwprintw(dt_win, 6, 20, "%-3d", pause);
		}
	}
					/* set 'em */
	param->cdelay = cdelay;
	param->pause = pause;
					/* save 'em to disk ? */
	if (yes_prompt(dt_win, 7, 12, A_BOLD, "Save to disk")) {
		if (update_param()) {
			touchwin(dt_win);
			wrefresh(dt_win);
		}
	}

	delwin(dt_win);
	return;
}
